#define RX_PULSESHAPER_1200_GAIN        1.000000f
#define RX_PULSESHAPER_1200_COEFF_SETS  12
static const complexf_t rx_pulseshaper_1200[RX_PULSESHAPER_1200_COEFF_SETS][37] =
{
    {
        {   0.0005944581f,   -0.0018295539f},     /* Filter 0 */
        {   0.0038355882f,   -0.0012462581f},
        {   0.0049609968f,    0.0036043752f},
        {  -0.0000000000f,    0.0078656419f},
        {  -0.0071488562f,    0.0051939480f},
        {  -0.0082219847f,   -0.0026714848f},
        {  -0.0021426098f,   -0.0065942748f},
        {   0.0020161991f,   -0.0027750599f},
        {  -0.0020114800f,   -0.0000000000f},
        {  -0.0055144152f,   -0.0075899414f},
        {   0.0057163992f,   -0.0175932678f},
        {   0.0275887139f,   -0.0089641165f},
        {   0.0326864751f,    0.0237481142f},
        {  -0.0000000000f,    0.0520524432f},
        {  -0.0511755900f,    0.0371812426f},
        {  -0.0697114085f,   -0.0226506097f},
        {  -0.0251880617f,   -0.0775208828f},
        {   0.0513295208f,   -0.0706490244f},
        {   0.0903420234f,    0.0000000000f},
        {   0.0531017090f,    0.0730882322f},
        {  -0.0269855260f,    0.0830529093f},
        {  -0.0775208828f,    0.0251880617f},
        {  -0.0593000660f,   -0.0430840199f},
        {  -0.0000000000f,   -0.0632565081f},
        {   0.0421113111f,   -0.0305956585f},
        {   0.0384252560f,    0.0124851225f},
        {   0.0089641165f,    0.0275887139f},
        {  -0.0108732375f,    0.0149657275f},
        {  -0.0093816835f,    0.0000000000f},
        {  -0.0011823183f,   -0.0016273215f},
        {  -0.0010599786f,    0.0032622786f},
        {  -0.0065942748f,    0.0021426098f},
        {  -0.0069940380f,   -0.0050814660f},
        {  -0.0000000000f,   -0.0088364722f},
        {   0.0063634379f,   -0.0046233083f},
        {   0.0058320016f,    0.0018949322f},
        {   0.0012462581f,    0.0038355882f}
    },
    {
        {   0.0006465801f,   -0.0019899690f},     /* Filter 1 */
        {   0.0040066013f,   -0.0013018237f},
        {   0.0050934529f,    0.0037006101f},
        {  -0.0000000000f,    0.0079812854f},
        {  -0.0071761839f,    0.0052138028f},
        {  -0.0081457795f,   -0.0026467242f},
        {  -0.0020744514f,   -0.0063845049f},
        {   0.0017937337f,   -0.0024688626f},
        {  -0.0025533503f,   -0.0000000000f},
        {  -0.0059239838f,   -0.0081536643f},
        {   0.0059724768f,   -0.0183813935f},
        {   0.0284672348f,   -0.0092495653f},
        {   0.0334715400f,    0.0243184973f},
        {  -0.0000000000f,    0.0530130803f},
        {  -0.0518963804f,    0.0377049274f},
        {  -0.0704369116f,   -0.0228863399f},
        {  -0.0253682062f,   -0.0780753105f},
        {   0.0515426342f,   -0.0709423499f},
        {   0.0904586247f,    0.0000000000f},
        {   0.0530207977f,    0.0729768673f},
        {  -0.0268674426f,    0.0826894857f},
        {  -0.0769505513f,    0.0250027498f},
        {  -0.0586725740f,   -0.0426281202f},
        {  -0.0000000000f,   -0.0623574663f},
        {   0.0413316408f,   -0.0300291948f},
        {   0.0375040844f,    0.0121858157f},
        {   0.0086805868f,    0.0267160989f},
        {  -0.0103918880f,    0.0143032067f},
        {  -0.0086971142f,    0.0000000000f},
        {  -0.0008717462f,   -0.0011998558f},
        {  -0.0011727478f,    0.0036093465f},
        {  -0.0067921410f,    0.0022069004f},
        {  -0.0070502812f,   -0.0051223291f},
        {  -0.0000000000f,   -0.0087945988f},
        {   0.0062655968f,   -0.0045522226f},
        {   0.0056738985f,    0.0018435614f},
        {   0.0011906836f,    0.0036645473f}
    },
    {
        {   0.0006992621f,   -0.0021521075f},     /* Filter 2 */
        {   0.0041774074f,   -0.0013573219f},
        {   0.0052236926f,    0.0037952348f},
        {  -0.0000000000f,    0.0080913986f},
        {  -0.0071967801f,    0.0052287668f},
        {  -0.0080593114f,   -0.0026186290f},
        {  -0.0020023867f,   -0.0061627125f},
        {   0.0015632808f,   -0.0021516714f},
        {  -0.0031086542f,   -0.0000000000f},
        {  -0.0063406470f,   -0.0087271518f},
        {   0.0062314920f,   -0.0191785603f},
        {   0.0293513452f,   -0.0095368301f},
        {   0.0342577560f,    0.0248897166f},
        {  -0.0000000000f,    0.0539702141f},
        {  -0.0526102914f,    0.0382236141f},
        {  -0.0711499279f,   -0.0231180130f},
        {  -0.0255430962f,   -0.0786135668f},
        {   0.0517441335f,   -0.0712196898f},
        {   0.0905540931f,    0.0000000000f},
        {   0.0529275462f,    0.0728485177f},
        {  -0.0267433682f,    0.0823076239f},
        {  -0.0763645934f,    0.0248123605f},
        {  -0.0580350475f,   -0.0421649301f},
        {  -0.0000000000f,   -0.0614507444f},
        {   0.0405498128f,   -0.0294611635f},
        {   0.0365850135f,    0.0118871915f},
        {   0.0083990788f,    0.0258497066f},
        {  -0.0099164224f,    0.0136487845f},
        {  -0.0080249289f,    0.0000000000f},
        {  -0.0005691347f,   -0.0007833467f},
        {  -0.0012813449f,    0.0039435742f},
        {  -0.0069782257f,    0.0022673630f},
        {  -0.0070980966f,   -0.0051570691f},
        {  -0.0000000000f,   -0.0087448582f},
        {   0.0061636632f,   -0.0044781635f},
        {   0.0055136150f,    0.0017914821f},
        {   0.0011351585f,    0.0034936588f}
    },
    {
        {   0.0007524586f,   -0.0023158293f},     /* Filter 3 */
        {   0.0043478209f,   -0.0014126926f},
        {   0.0053515345f,    0.0038881174f},
        {  -0.0000000000f,    0.0081957427f},
        {  -0.0072104667f,    0.0052387107f},
        {  -0.0079624054f,   -0.0025871424f},
        {  -0.0019263796f,   -0.0059287867f},
        {   0.0013248222f,   -0.0018234614f},
        {  -0.0036773273f,   -0.0000000000f},
        {  -0.0067643060f,   -0.0093102685f},
        {   0.0064933625f,   -0.0199845150f},
        {   0.0302407132f,   -0.0098258033f},
        {   0.0350448010f,    0.0254615384f},
        {  -0.0000000000f,    0.0549234238f},
        {  -0.0533169949f,    0.0387370642f},
        {  -0.0718501024f,   -0.0233455134f},
        {  -0.0257126472f,   -0.0791353911f},
        {   0.0519339297f,   -0.0714809219f},
        {   0.0906283998f,    0.0000000000f},
        {   0.0528219995f,    0.0727032451f},
        {  -0.0266133659f,    0.0819075180f},
        {  -0.0757632982f,    0.0246169878f},
        {  -0.0573877799f,   -0.0416946627f},
        {  -0.0000000000f,   -0.0605367479f},
        {   0.0397661628f,   -0.0288918084f},
        {   0.0356684082f,    0.0115893684f},
        {   0.0081196950f,    0.0249898517f},
        {  -0.0094469844f,    0.0130026585f},
        {  -0.0073652682f,    0.0000000000f},
        {  -0.0002745080f,   -0.0003778279f},
        {  -0.0013857854f,    0.0042650089f},
        {  -0.0071526572f,    0.0023240392f},
        {  -0.0071376445f,   -0.0051858023f},
        {  -0.0000000000f,   -0.0086874779f},
        {   0.0060578290f,   -0.0044012704f},
        {   0.0053513607f,    0.0017387625f},
        {   0.0010797387f,    0.0033230939f}
    },
    {
        {   0.0008061228f,   -0.0024809909f},     /* Filter 4 */
        {   0.0045176541f,   -0.0014678748f},
        {   0.0054767942f,    0.0039791239f},
        {  -0.0000000000f,    0.0082940836f},
        {  -0.0072170648f,    0.0052435045f},
        {  -0.0078548930f,   -0.0025522094f},
        {  -0.0018463962f,   -0.0056826233f},
        {   0.0010783437f,   -0.0014842128f},
        {  -0.0042592917f,   -0.0000000000f},
        {  -0.0071948553f,   -0.0099028688f},
        {   0.0067580050f,   -0.0207990006f},
        {   0.0311350075f,   -0.0101163772f},
        {   0.0358323492f,    0.0260337255f},
        {  -0.0000000000f,    0.0558722880f},
        {  -0.0540161669f,    0.0392450425f},
        {  -0.0725371076f,   -0.0235687350f},
        {  -0.0258767749f,   -0.0796405240f},
        {   0.0521119220f,   -0.0717259073f},
        {   0.0906815023f,    0.0000000000f},
        {   0.0527042181f,    0.0725411330f},
        {  -0.0264775002f,    0.0814893666f},
        {  -0.0751469523f,    0.0244167249f},
        {  -0.0567310773f,   -0.0412175403f},
        {  -0.0000000000f,   -0.0596159016f},
        {   0.0389810295f,   -0.0283213757f},
        {   0.0347546342f,    0.0112924652f},
        {   0.0078425317f,    0.0241368306f},
        {  -0.0089837114f,    0.0123650179f},
        {  -0.0067182711f,    0.0000000000f},
        {   0.0000121147f,    0.0000166744f},
        {  -0.0014860895f,    0.0045737133f},
        {  -0.0073155681f,    0.0023769722f},
        {  -0.0071690834f,   -0.0052086440f},
        {  -0.0000000000f,   -0.0086226877f},
        {   0.0059482846f,   -0.0043216818f},
        {   0.0051873402f,    0.0016854690f},
        {   0.0010244801f,    0.0031530254f}
    },
    {
        {   0.0008602070f,   -0.0026474449f},     /* Filter 5 */
        {   0.0046867184f,   -0.0015228071f},
        {   0.0055992856f,    0.0040681191f},
        {  -0.0000000000f,    0.0083861837f},
        {  -0.0072163979f,    0.0052430199f},
        {  -0.0077366100f,   -0.0025137770f},
        {  -0.0017624047f,   -0.0054241238f},
        {   0.0008238360f,   -0.0011339130f},
        {  -0.0048544647f,   -0.0000000000f},
        {  -0.0076321872f,   -0.0105048045f},
        {   0.0070253327f,   -0.0216217509f},
        {   0.0320338908f,   -0.0104084421f},
        {   0.0366200761f,    0.0266060427f},
        {  -0.0000000000f,    0.0568163868f},
        {  -0.0547074810f,    0.0397473115f},
        {  -0.0732106139f,   -0.0237875704f},
        {  -0.0260354008f,   -0.0801287243f},
        {   0.0522780261f,   -0.0719545300f},
        {   0.0907133744f,    0.0000000000f},
        {   0.0525742489f,    0.0723622457f},
        {  -0.0263358366f,    0.0810533708f},
        {  -0.0745158480f,    0.0242116667f},
        {  -0.0560652526f,   -0.0407337903f},
        {  -0.0000000000f,   -0.0586886174f},
        {   0.0381947481f,   -0.0277501089f},
        {   0.0338440552f,    0.0109966001f},
        {   0.0075676877f,    0.0232909479f},
        {  -0.0085267369f,    0.0117360466f},
        {  -0.0060840594f,    0.0000000000f},
        {   0.0002907188f,    0.0004001402f},
        {  -0.0015822779f,    0.0048697507f},
        {  -0.0074671003f,    0.0024262080f},
        {  -0.0071925765f,   -0.0052257127f},
        {  -0.0000000000f,   -0.0085507200f},
        {   0.0058352199f,   -0.0042395355f},
        {   0.0050217593f,    0.0016316685f},
        {   0.0009694368f,    0.0029836196f}
    },
    {
        {   0.0009146617f,   -0.0028150393f},     /* Filter 6 */
        {   0.0048548193f,   -0.0015774264f},
        {   0.0057188240f,    0.0041549688f},
        {  -0.0000000000f,    0.0084718067f},
        {  -0.0072082928f,    0.0052371313f},
        {  -0.0076073982f,   -0.0024717935f},
        {  -0.0016743743f,   -0.0051531942f},
        {   0.0005612938f,   -0.0007725546f},
        {  -0.0054627541f,   -0.0000000000f},
        {  -0.0080761873f,   -0.0111159182f},
        {   0.0072952570f,   -0.0224524923f},
        {   0.0329370235f,   -0.0107018877f},
        {   0.0374076526f,    0.0271782505f},
        {  -0.0000000000f,    0.0577553021f},
        {  -0.0553906148f,    0.0402436373f},
        {  -0.0738702978f,   -0.0240019147f},
        {  -0.0261884465f,   -0.0805997506f},
        {   0.0524321605f,   -0.0721666777f},
        {   0.0907240049f,    0.0000000000f},
        {   0.0524321605f,    0.0721666777f},
        {  -0.0261884465f,    0.0805997506f},
        {  -0.0738702978f,    0.0240019147f},
        {  -0.0553906148f,   -0.0402436373f},
        {  -0.0000000000f,   -0.0577553021f},
        {   0.0374076525f,   -0.0271782505f},
        {   0.0329370235f,    0.0107018876f},
        {   0.0072952570f,    0.0224524923f},
        {  -0.0080761873f,    0.0111159182f},
        {  -0.0054627541f,    0.0000000000f},
        {   0.0005612938f,    0.0007725546f},
        {  -0.0016743743f,    0.0051531942f},
        {  -0.0076073982f,    0.0024717935f},
        {  -0.0072082928f,   -0.0052371313f},
        {  -0.0000000000f,   -0.0084718067f},
        {   0.0057188240f,   -0.0041549688f},
        {   0.0048548193f,    0.0015774264f},
        {   0.0009146617f,    0.0028150393f}
    },
    {
        {   0.0009694368f,   -0.0029836196f},     /* Filter 7 */
        {   0.0050217593f,   -0.0016316685f},
        {   0.0058352199f,    0.0042395355f},
        {  -0.0000000000f,    0.0085507200f},
        {  -0.0071925765f,    0.0052257127f},
        {  -0.0074671003f,   -0.0024262080f},
        {  -0.0015822779f,   -0.0048697507f},
        {   0.0002907188f,   -0.0004001402f},
        {  -0.0060840594f,   -0.0000000000f},
        {  -0.0085267369f,   -0.0117360466f},
        {   0.0075676877f,   -0.0232909479f},
        {   0.0338440552f,   -0.0109966001f},
        {   0.0381947481f,    0.0277501089f},
        {  -0.0000000000f,    0.0586886174f},
        {  -0.0560652526f,    0.0407337903f},
        {  -0.0745158480f,   -0.0242116667f},
        {  -0.0263358366f,   -0.0810533708f},
        {   0.0525742489f,   -0.0723622457f},
        {   0.0907133744f,    0.0000000000f},
        {   0.0522780261f,    0.0719545299f},
        {  -0.0260354008f,    0.0801287243f},
        {  -0.0732106139f,    0.0237875704f},
        {  -0.0547074810f,   -0.0397473115f},
        {  -0.0000000000f,   -0.0568163868f},
        {   0.0366200761f,   -0.0266060427f},
        {   0.0320338908f,    0.0104084421f},
        {   0.0070253327f,    0.0216217509f},
        {  -0.0076321872f,    0.0105048045f},
        {  -0.0048544647f,    0.0000000000f},
        {   0.0008238360f,    0.0011339130f},
        {  -0.0017624047f,    0.0054241238f},
        {  -0.0077366100f,    0.0025137770f},
        {  -0.0072163979f,   -0.0052430199f},
        {  -0.0000000000f,   -0.0083861837f},
        {   0.0055992856f,   -0.0040681191f},
        {   0.0046867184f,    0.0015228071f},
        {   0.0008602070f,    0.0026474449f}
    },
    {
        {   0.0010244801f,   -0.0031530254f},     /* Filter 8 */
        {   0.0051873402f,   -0.0016854690f},
        {   0.0059482846f,    0.0043216818f},
        {  -0.0000000000f,    0.0086226877f},
        {  -0.0071690834f,    0.0052086440f},
        {  -0.0073155681f,   -0.0023769722f},
        {  -0.0014860895f,   -0.0045737133f},
        {   0.0000121147f,   -0.0000166744f},
        {  -0.0067182711f,   -0.0000000000f},
        {  -0.0089837114f,   -0.0123650179f},
        {   0.0078425317f,   -0.0241368306f},
        {   0.0347546343f,   -0.0112924652f},
        {   0.0389810295f,    0.0283213757f},
        {  -0.0000000000f,    0.0596159016f},
        {  -0.0567310773f,    0.0412175403f},
        {  -0.0751469523f,   -0.0244167249f},
        {  -0.0264775002f,   -0.0814893666f},
        {   0.0527042181f,   -0.0725411330f},
        {   0.0906815023f,    0.0000000000f},
        {   0.0521119220f,    0.0717259073f},
        {  -0.0258767749f,    0.0796405240f},
        {  -0.0725371076f,    0.0235687350f},
        {  -0.0540161669f,   -0.0392450425f},
        {  -0.0000000000f,   -0.0558722880f},
        {   0.0358323491f,   -0.0260337255f},
        {   0.0311350075f,    0.0101163772f},
        {   0.0067580050f,    0.0207990006f},
        {  -0.0071948553f,    0.0099028688f},
        {  -0.0042592917f,    0.0000000000f},
        {   0.0010783437f,    0.0014842128f},
        {  -0.0018463962f,    0.0056826233f},
        {  -0.0078548930f,    0.0025522094f},
        {  -0.0072170648f,   -0.0052435045f},
        {  -0.0000000000f,   -0.0082940836f},
        {   0.0054767942f,   -0.0039791239f},
        {   0.0045176541f,    0.0014678748f},
        {   0.0008061228f,    0.0024809909f}
    },
    {
        {   0.0010797387f,   -0.0033230939f},     /* Filter 9 */
        {   0.0053513607f,   -0.0017387625f},
        {   0.0060578290f,    0.0044012704f},
        {  -0.0000000000f,    0.0086874779f},
        {  -0.0071376445f,    0.0051858023f},
        {  -0.0071526572f,   -0.0023240392f},
        {  -0.0013857854f,   -0.0042650089f},
        {  -0.0002745080f,    0.0003778279f},
        {  -0.0073652682f,   -0.0000000000f},
        {  -0.0094469844f,   -0.0130026585f},
        {   0.0081196950f,   -0.0249898517f},
        {   0.0356684082f,   -0.0115893684f},
        {   0.0397661628f,    0.0288918084f},
        {  -0.0000000000f,    0.0605367479f},
        {  -0.0573877799f,    0.0416946627f},
        {  -0.0757632982f,   -0.0246169878f},
        {  -0.0266133659f,   -0.0819075180f},
        {   0.0528219995f,   -0.0727032451f},
        {   0.0906283998f,    0.0000000000f},
        {   0.0519339297f,    0.0714809218f},
        {  -0.0257126472f,    0.0791353911f},
        {  -0.0718501024f,    0.0233455134f},
        {  -0.0533169949f,   -0.0387370642f},
        {  -0.0000000000f,   -0.0549234238f},
        {   0.0350448010f,   -0.0254615383f},
        {   0.0302407132f,    0.0098258033f},
        {   0.0064933625f,    0.0199845150f},
        {  -0.0067643060f,    0.0093102685f},
        {  -0.0036773273f,    0.0000000000f},
        {   0.0013248222f,    0.0018234614f},
        {  -0.0019263796f,    0.0059287867f},
        {  -0.0079624054f,    0.0025871424f},
        {  -0.0072104667f,   -0.0052387107f},
        {  -0.0000000000f,   -0.0081957427f},
        {   0.0053515345f,   -0.0038881174f},
        {   0.0043478209f,    0.0014126926f},
        {   0.0007524586f,    0.0023158293f}
    },
    {
        {   0.0011351585f,   -0.0034936588f},     /* Filter 10 */
        {   0.0055136150f,   -0.0017914821f},
        {   0.0061636632f,    0.0044781635f},
        {  -0.0000000000f,    0.0087448582f},
        {  -0.0070980966f,    0.0051570691f},
        {  -0.0069782257f,   -0.0022673630f},
        {  -0.0012813449f,   -0.0039435742f},
        {  -0.0005691347f,    0.0007833467f},
        {  -0.0080249289f,   -0.0000000000f},
        {  -0.0099164224f,   -0.0136487845f},
        {   0.0083990788f,   -0.0258497066f},
        {   0.0365850135f,   -0.0118871915f},
        {   0.0405498128f,    0.0294611635f},
        {  -0.0000000000f,    0.0614507444f},
        {  -0.0580350475f,    0.0421649301f},
        {  -0.0763645934f,   -0.0248123605f},
        {  -0.0267433682f,   -0.0823076239f},
        {   0.0529275462f,   -0.0728485177f},
        {   0.0905540931f,    0.0000000000f},
        {   0.0517441335f,    0.0712196898f},
        {  -0.0255430962f,    0.0786135668f},
        {  -0.0711499279f,    0.0231180130f},
        {  -0.0526102914f,   -0.0382236141f},
        {  -0.0000000000f,   -0.0539702141f},
        {   0.0342577560f,   -0.0248897166f},
        {   0.0293513451f,    0.0095368301f},
        {   0.0062314920f,    0.0191785603f},
        {  -0.0063406470f,    0.0087271518f},
        {  -0.0031086542f,    0.0000000000f},
        {   0.0015632808f,    0.0021516714f},
        {  -0.0020023867f,    0.0061627125f},
        {  -0.0080593114f,    0.0026186290f},
        {  -0.0071967801f,   -0.0052287668f},
        {  -0.0000000000f,   -0.0080913986f},
        {   0.0052236926f,   -0.0037952348f},
        {   0.0041774074f,    0.0013573219f},
        {   0.0006992621f,    0.0021521075f}
    },
    {
        {   0.0011906836f,   -0.0036645473f},     /* Filter 11 */
        {   0.0056738985f,   -0.0018435614f},
        {   0.0062655968f,    0.0045522226f},
        {  -0.0000000000f,    0.0087945988f},
        {  -0.0070502812f,    0.0051223291f},
        {  -0.0067921410f,   -0.0022069004f},
        {  -0.0011727478f,   -0.0036093465f},
        {  -0.0008717462f,    0.0011998558f},
        {  -0.0086971142f,   -0.0000000000f},
        {  -0.0103918880f,   -0.0143032067f},
        {   0.0086805868f,   -0.0267160990f},
        {   0.0375040844f,   -0.0121858157f},
        {   0.0413316408f,    0.0300291948f},
        {  -0.0000000000f,    0.0623574663f},
        {  -0.0586725740f,    0.0426281202f},
        {  -0.0769505513f,   -0.0250027498f},
        {  -0.0268674426f,   -0.0826894857f},
        {   0.0530207977f,   -0.0729768673f},
        {   0.0904586247f,    0.0000000000f},
        {   0.0515426342f,    0.0709423499f},
        {  -0.0253682062f,    0.0780753105f},
        {  -0.0704369116f,    0.0228863399f},
        {  -0.0518963804f,   -0.0377049274f},
        {  -0.0000000000f,   -0.0530130803f},
        {   0.0334715400f,   -0.0243184973f},
        {   0.0284672348f,    0.0092495653f},
        {   0.0059724768f,    0.0183813935f},
        {  -0.0059239838f,    0.0081536643f},
        {  -0.0025533503f,    0.0000000000f},
        {   0.0017937337f,    0.0024688626f},
        {  -0.0020744514f,    0.0063845049f},
        {  -0.0081457795f,    0.0026467242f},
        {  -0.0071761839f,   -0.0052138028f},
        {  -0.0000000000f,   -0.0079812854f},
        {   0.0050934529f,   -0.0037006101f},
        {   0.0040066013f,    0.0013018237f},
        {   0.0006465801f,    0.0019899690f}
    }
};
